## For data analysts and scientists

* Use your team's best matching methods when retrieving entities, always
* Measurably improve methodologies when they don't work for you
* When you link new data, allow others to use your work easily and securely

[:octicons-download-16: Install client](./client/install.md){ .md-button }

## For data architects and engineers

* Reconcile entities across disparate data
* Rationalise about the quality of different entity matching pipelines and serve up the best
* Run matching pipelines without recomputing them every time
* Lay the foundation for the nouns of a semantic layer

[:octicons-download-16: Install server](./server/install.md){ .md-button }

## For service owners

* Understand the broader business entities in your service, not just what you have
* Enrich other services with data generated in yours without giving away any permissioning powers
* Empower your users to label matched entities and let other services use that information

[:octicons-download-16: Install client](./client/install.md){ .md-button }
[:octicons-download-16: Install server](./server/install.md){ .md-button }